@@ -32,7 +32,7 @@ no indirect 'fatal';
 no multidimensional;
 use warnings 'once';
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use UI::Various::core;
 use UI::Various::Text;
@@ -69,7 +69,7 @@ our @EXPORT_OK = qw();
 
 Prepare output of the UI element by determining and returning the space it
 wants or needs.  I<The method should only be called from
-C<UI::Various::Curses> container elements!>
+C<UI::Various::RichTerm> container elements!>
 
 =head3 returns:
 
@@ -122,7 +122,7 @@ the rectangular text box for UI element
 sub _show($$$$$$)
 {
     my ($self, $prefix, $width, $height) = @_;
-    return $self->_format($prefix, '', $self->text, '', $width, $height);
+    return $self->_format($prefix, '', '', $self->text, '', '', $width, $height);
 }
 
 1;
